@@ -50,7 +50,7 @@ package Astro::Coord::ECI::Star;
 use strict;
 use warnings;
 
-our $VERSION = '0.051';
+our $VERSION = '0.052';
 
 use base qw{Astro::Coord::ECI};
 
@@ -121,9 +121,11 @@ sub __almanac_event_type_iterator {
 
     my $inx = 0;
 
+    my $horizon = $station->__get_almanac_horizon();
+
     my $name = $self->get ('name') || $self->get ('id') || 'star';
     my @events = (
-	[ $station, next_elevation => [ $self, 0, 1 ], 'horizon',
+	[ $station, next_elevation => [ $self, $horizon, 1 ], 'horizon',
 		[ "$name sets", "$name rises"] ],
 	[ $station, next_meridian => [ $self ], 'transit',
 		[ undef, "$name transits meridian"] ],
