@@ -121,7 +121,7 @@ use warnings;
 
 use base qw{Astro::Coord::ECI::TLE};
 
-our $VERSION = '0.051';
+our $VERSION = '0.052';
 
 use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils qw{:all};
@@ -138,15 +138,21 @@ use constant MMAPHI => deg2rad (-130);	# The MMAs are at an angle of
 					# them "flat".
 use constant TWOPIOVER3 => TWOPI / 3;	# 120 degrees, in radians.
 
+use constant STATUS_IN_SERVICE => 0;
+use constant STATUS_SPARE => 1;
+use constant STATUS_TUMBLING => 2;
+
 my %mutator = (
     algorithm => sub {
-	my $method = "_flare_$_[2]";
-	croak "Error - Unknown flare algorithm name $_[2]"
-	    unless $_[0]->can ($method);
-	$_[0]->{&ATTRIBUTE_KEY}{$_[1]} = $_[2];
-	$_[0]->{&ATTRIBUTE_KEY}{_algorithm_method} = $method;
-	},
-    );
+	my ( $self, $name, $value ) = @_;
+	my $method = "_flare_$value";
+	croak "Error - Unknown flare algorithm name $value"
+	    unless $self->can ($method);
+	$self->{&ATTRIBUTE_KEY}{$name} = $value;
+	$self->{&ATTRIBUTE_KEY}{_algorithm_method} = $method;
+    },
+    status	=> \&_set_operational_status,
+);
 foreach my $key (qw{am day extinction max_mirror_angle pm status zone}) {
     $mutator{$key} = sub {$_[0]->{&ATTRIBUTE_KEY}{$_[1]} = $_[2]};
 }
@@ -1507,19 +1513,108 @@ sub set {
 }
 
 # For use of -am and -pm
-sub _time_in_zone {
-    my ( $self, $time ) = @_;
+{
+    my $date_time_available = eval {
+	load_module( 'DateTime' );
+	load_module( 'DateTime::TimeZone' );
+	1;
+    };
 
-    defined( my $zone = $self->get( 'zone' ) )
-	or return localtime $time;
+    sub _time_in_zone {
+	my ( $self, $time ) = @_;
 
-    looks_like_number( $zone )
-	and return gmtime( $zone * 3600 + $time );
+	defined( my $zone = $self->get( 'zone' ) )
+	    or return localtime $time;
 
-    # TODO use DateTime if available
+	looks_like_number( $zone )
+	    and return gmtime( $zone * 3600 + $time );
 
-    local $ENV{TZ} = $zone;
-    return localtime $time;
+	if ( $date_time_available ) {
+
+	    my $dt = DateTime->from_epoch(
+		epoch		=> $time,
+		time_zone	=> $zone,
+	    );
+
+	    my @localtime = map { $dt->$_() } qw{ second minute hour day
+	    month_0 year day_of_week_0 day_of_year_0 is_dst };
+	    $localtime[5] -= 1900;
+	    return @localtime;
+
+	} else {
+
+	    local $ENV{TZ} = $zone;
+	    return localtime $time;
+
+	}
+    }
+}
+
+sub __parse_name {
+    my ( $self, $name ) = @_;
+    defined $name
+	and $name =~ s/ \s* [[] ( \S ) []] \s* \z //smx
+	and $self->_set_operational_status( status => $1 );
+    return $self->SUPER::__parse_name( $name );
+}
+
+{
+    my @encode_status;
+    $encode_status[STATUS_IN_SERVICE]	= '+';
+    $encode_status[STATUS_SPARE]	= 'S';
+    $encode_status[STATUS_TUMBLING]	= '-';
+
+    sub __encode_operational_status {
+	my ( $self, $name, $status ) = @_;
+	defined $status
+	    or $status = $self->get( 'status' );
+	defined $encode_status[ $status ]
+	    or return STATUS_TUMBLING;
+	return $encode_status[ $status ];
+    }
+}
+
+
+{
+
+    my %status_map = (
+	STATUS_IN_SERVICE()	=> STATUS_IN_SERVICE,
+	''			=> STATUS_IN_SERVICE,
+	'+'			=> STATUS_IN_SERVICE,
+	STATUS_SPARE()		=> STATUS_SPARE,
+	'?'			=> STATUS_SPARE,
+	'S'			=> STATUS_SPARE,
+	's'			=> STATUS_SPARE,
+    );
+
+    sub __decode_operational_status {
+	my ( $value ) = @_;
+	defined $value
+	    or return STATUS_IN_SERVICE;;
+	defined $status_map{$value}
+	    or return STATUS_TUMBLING;
+	return $status_map{$value};
+    }
+}
+
+sub _set_operational_status {
+    my ( $self, $name, $value ) = @_;
+    $self->{&ATTRIBUTE_KEY}{$name} = __decode_operational_status( $value );
+    return $self;
+}
+
+{
+    my %json_map = (
+	operational_status	=> \&__encode_operational_status,
+    );
+
+    sub TO_JSON {
+	my ( $self ) = @_;
+	return $self->__to_json(
+	    \%json_map,
+	    $self->SUPER::TO_JSON(),
+	);
+    }
 }
 
 1;
@@ -1608,7 +1703,7 @@ Technically, the default is 0. But if the object is manufactured by
 Astro::Coord::ECI::TLE->parse(), the status will be set based on the
 internal status table in Astro::Coord::ECI::TLE.
 
-=item zone (number)
+=item zone (number or string)
 
 This attribute is used to determine whether a flare took place in the
 C<am> or C<pm>. It can be set to a number of possible values:
@@ -1619,15 +1714,17 @@ that is.
 * A numeric value is interpreted as an offset in hours east of
 Greenwich; hours west are negative.
 
-* Anything else is interpreted as a zone name; $ENV{TZ} is set to this,
-and then C<localtime()> is called. Whether this has the desired effect
-depends on your operating system.
+* Anything else is interpreted as a zone name. If L<DateTime|DateTime>
+is available, it is used to convert the time to the named zone, throwing
+an exception if the zone name is not recognized.
+
+Otherwise, $ENV{TZ} is set to the zone, and then C<localtime()> is
+called. Whether this has the desired effect depends on your operating
+system.
 
 Yes, this is a bit of a crock, but I realized (B<after> putting out
 0.036, with the Iridium flare tests that anyone can run) that I needed
-to do B<something> to get a user's-zone-independent test. Eventually I
-may make use of DateTime if that is available, but I do not want to make
-that a prerequisite.
+to do B<something> to get a user's-zone-independent test.
 
 The default is C<undef>.
 
